@@ -47,16 +47,16 @@ sub with_times {
     ->search({},
       {
         '+columns' => {
-          uptime_age => \("replace(age(timestamp 'epoch' + uptime / 100 * interval '1 second', "
+          uptime_age => \("replace(age(timestamp 'epoch' + me.uptime / 100 * interval '1 second', "
             ."timestamp '1970-01-01 00:00:00-00')::text, 'mon', 'month')"),
           first_seen_stamp    => \"to_char(me.creation, 'YYYY-MM-DD HH24:MI')",
-          last_discover_stamp => \"to_char(last_discover, 'YYYY-MM-DD HH24:MI')",
-          last_macsuck_stamp  => \"to_char(last_macsuck,  'YYYY-MM-DD HH24:MI')",
-          last_arpnip_stamp   => \"to_char(last_arpnip,   'YYYY-MM-DD HH24:MI')",
+          last_discover_stamp => \"to_char(me.last_discover, 'YYYY-MM-DD HH24:MI')",
+          last_macsuck_stamp  => \"to_char(me.last_macsuck,  'YYYY-MM-DD HH24:MI')",
+          last_arpnip_stamp   => \"to_char(me.last_arpnip,   'YYYY-MM-DD HH24:MI')",
           since_first_seen    => \"extract(epoch from (age(now(), me.creation)))",
-          since_last_discover => \"extract(epoch from (age(now(), last_discover)))",
-          since_last_macsuck  => \"extract(epoch from (age(now(), last_macsuck)))",
-          since_last_arpnip   => \"extract(epoch from (age(now(), last_arpnip)))",
+          since_last_discover => \"extract(epoch from (age(now(), me.last_discover)))",
+          since_last_macsuck  => \"extract(epoch from (age(now(), me.last_macsuck)))",
+          since_last_arpnip   => \"extract(epoch from (age(now(), me.last_arpnip)))",
         },
       });
 }
